@@ -869,7 +869,6 @@ class SpecialMethodTests(unittest.TestCase, Util):
             self.assertEqual(any(a), a.any())
             self.assertEqual(any(a.tolist()), a.any())
 
-
     def test_repr(self):
         r = repr(bitarray())
         self.assertEqual(r, "bitarray()")
@@ -885,7 +884,6 @@ class SpecialMethodTests(unittest.TestCase, Util):
             self.assertEqual(a, b)
             self.check_obj(b)
 
-
     def test_copy(self):
         for a in self.randombitarrays():
             b = a.copy()
@@ -900,7 +898,6 @@ class SpecialMethodTests(unittest.TestCase, Util):
             self.assertFalse(b is a)
             self.assertEQUAL(a, b)
 
-
     def assertReallyEqual(self, a, b):
         # assertEqual first, because it will have a good message if the
         # assertion fails.
@@ -942,9 +939,19 @@ class SpecialMethodTests(unittest.TestCase, Util):
             b = a.copy()
             self.assertReallyEqual(a, b)
             n = len(a)
-            b[n - 1] = not b[n - 1]  # flip the last bit
+            b.invert(n - 1)  # flip last bit
             self.assertReallyNotEqual(a, b)
 
+    def test_sizeof(self):
+        a = bitarray()
+        size = sys.getsizeof(a)
+        self.assertEqual(size, a.__sizeof__())
+        self.assertIsInstance(size, int if is_py3k else (int, long))
+        self.assertTrue(size < 200)
+        a = bitarray(8000)
+        self.assertTrue(sys.getsizeof(a) > 1000)
+
+
 tests.append(SpecialMethodTests)
 
 # ---------------------------------------------------------------------------
@@ -1170,14 +1177,6 @@ class NumberMethodsTests(unittest.TestCase, Util):
         self.assertEQUAL(a, bitarray('010100101'))
 
     def test_invert(self):
-        a = bitarray()
-        a.invert()
-        self.assertEQUAL(a, bitarray())
-
-        a = bitarray('11011')
-        a.invert()
-        self.assertEQUAL(a, bitarray('00100'))
-
         a = bitarray('11011')
         b = ~a
         self.assertEQUAL(b, bitarray('00100'))
@@ -1338,7 +1337,7 @@ tests.append(ExtendTests)
 
 class MethodTests(unittest.TestCase, Util):
 
-    def test_append(self):
+    def test_append_simple(self):
         a = bitarray()
         a.append(True)
         a.append(False)
@@ -1352,6 +1351,7 @@ class MethodTests(unittest.TestCase, Util):
         a.append('a')
         self.assertEQUAL(a, bitarray('100011001'))
 
+    def test_append_random(self):
         for a in self.randombitarrays():
             aa = a.tolist()
             b = a
@@ -1362,7 +1362,6 @@ class MethodTests(unittest.TestCase, Util):
             b.append('')
             self.assertEQUAL(b, bitarray(aa + [1, 0], endian=a.endian()))
 
-
     def test_insert(self):
         a = bitarray()
         b = a
@@ -1382,7 +1381,6 @@ class MethodTests(unittest.TestCase, Util):
                 self.assertEqual(a.tolist(), aa)
                 self.check_obj(a)
 
-
     def test_index1(self):
         a = bitarray()
         for i in (True, False, 1, 0):
@@ -1547,7 +1545,6 @@ class MethodTests(unittest.TestCase, Util):
             self.assertEqual(a.count(1, i, j), s[i:j].count('1'))
             self.assertEqual(a.count(0, i, j), s[i:j].count('0'))
 
-
     def test_search(self):
         a = bitarray('')
         self.assertEqual(a.search(bitarray('0')), [])
@@ -1645,8 +1642,36 @@ class MethodTests(unittest.TestCase, Util):
                 self.assertEqual(b[len(a):],
                                  (len(b) - len(a)) * bitarray('0'))
 
+    def test_invert_simple(self):
+        a = bitarray()
+        a.invert()
+        self.assertEQUAL(a, bitarray())
 
-    def test_sort(self):
+        a = bitarray('11011')
+        a.invert()
+        self.assertEQUAL(a, bitarray('00100'))
+        a.invert(2)
+        self.assertEQUAL(a, bitarray('00000'))
+        a.invert(-1)
+        self.assertEQUAL(a, bitarray('00001'))
+
+    def test_invert_errors(self):
+        a = bitarray(5)
+        self.assertRaises(IndexError, a.invert, 5)
+        self.assertRaises(IndexError, a.invert, -6)
+        self.assertRaises(TypeError, a.invert, "A")
+        self.assertRaises(TypeError, a.invert, 0, 1)
+
+    def test_invert_random(self):
+        for a in self.randombitarrays(start=1):
+            b = a.copy()
+            c = a.copy()
+            i = randint(0, len(a) - 1)
+            b.invert(i)
+            c[i] = not c[i]
+            self.assertEQUAL(b, c)
+
+    def test_sort_simple(self):
         a = bitarray('1101000')
         a.sort()
         self.assertEqual(a, bitarray('0000111'))
@@ -1663,26 +1688,14 @@ class MethodTests(unittest.TestCase, Util):
 
         self.assertRaises(TypeError, a.sort, 'A')
 
-        N = 100000
-        a = bitarray(randint(N, N + 100))
-        for dum in range(100):
-            a[randint(0, N - 1)] = randint(0, 1)
-        b = a.tolist()
-        a.sort()
-        self.assertEqual(a, bitarray(sorted(b)))
-
-        for a in self.randombitarrays():
-            b = a.tolist()
-            ida = id(a)
-            rev = randint(0, 1)
-            a.sort(rev)
-            self.assertEqual(a, bitarray(sorted(b, reverse=rev)))
-            self.assertEqual(id(a), ida)
-
-
-    def test_reverse(self):
-        self.assertRaises(TypeError, bitarray().reverse, 42)
+    def test_sort_random(self):
+        for rev in 0, 1:
+            for a in self.randombitarrays():
+                b = a.tolist()
+                a.sort(rev)
+                self.assertEqual(a, bitarray(sorted(b, reverse=rev)))
 
+    def test_reverse_simple(self):
         for x, y in [('', ''), ('1', '1'), ('10', '01'), ('001', '100'),
                      ('1110', '0111'), ('11100', '00111'),
                      ('011000', '000110'), ('1101100', '0011011'),
@@ -1694,15 +1707,14 @@ class MethodTests(unittest.TestCase, Util):
             a.reverse()
             self.assertEQUAL(a, bitarray(y))
 
-        for a in self.randombitarrays():
-            aa = a.tolist()
-            b = bitarray(a)
-            ida = id(a)
-            a.reverse()
-            self.assertEqual(ida, id(a))
-            self.assertEQUAL(a, bitarray(aa[::-1], endian=a.endian()))
-            self.assertEqual(a, b[::-1])
+        self.assertRaises(TypeError, bitarray().reverse, 42)
 
+    def test_reverse_random(self):
+        for a in self.randombitarrays():
+            b = a.copy()
+            a.reverse()
+            self.assertEQUAL(a, bitarray(b.tolist()[::-1], endian=a.endian()))
+            self.assertEQUAL(a, b[::-1])
 
     def test_tolist(self):
         a = bitarray()
@@ -1715,18 +1727,7 @@ class MethodTests(unittest.TestCase, Util):
             a = bitarray(lst)
             self.assertEqual(a.tolist(), lst)
 
-
     def test_remove(self):
-        a = bitarray()
-        for i in (True, False, 1, 0):
-            self.assertRaises(ValueError, a.remove, i)
-
-        a = bitarray(21)
-        a.setall(0)
-        self.assertRaises(ValueError, a.remove, 1)
-        a.setall(1)
-        self.assertRaises(ValueError, a.remove, 0)
-
         a = bitarray('1010110')
         for val, res in [(False, '110110'), (True, '10110'),
                          (1, '0110'), (1, '010'), (0, '10'),
@@ -1740,8 +1741,18 @@ class MethodTests(unittest.TestCase, Util):
         self.assertTrue(b is a)
         self.assertEQUAL(b, bitarray('000011'))
 
+    def test_remove_errors(self):
+        a = bitarray()
+        for i in (True, False, 1, 0):
+            self.assertRaises(ValueError, a.remove, i)
 
-    def test_pop(self):
+        a = bitarray(21)
+        a.setall(0)
+        self.assertRaises(ValueError, a.remove, 1)
+        a.setall(1)
+        self.assertRaises(ValueError, a.remove, 0)
+
+    def test_pop_simple(self):
         for x, n, r, y in [('1', 0, True, ''),
                            ('0', -1, False, ''),
                            ('0011100', 3, True, '001100')]:
@@ -1754,6 +1765,7 @@ class MethodTests(unittest.TestCase, Util):
         self.assertEqual(a.pop(), False)
         self.assertRaises(IndexError, a.pop)
 
+    def test_pop_random(self):
         for a in self.randombitarrays():
             self.assertRaises(IndexError, a.pop, len(a))
             self.assertRaises(IndexError, a.pop, -len(a) - 1)
@@ -1773,7 +1785,6 @@ class MethodTests(unittest.TestCase, Util):
             self.assertEqual(a, bitarray(aa))
             self.check_obj(a)
 
-
     def test_clear(self):
         for a in self.randombitarrays():
             ida = id(a)
@@ -1806,8 +1817,7 @@ class MethodTests(unittest.TestCase, Util):
             self.assertTrue(a is b)
             self.check_obj(b)
 
-
-    def test_bytereverse(self):
+    def test_bytereverse_explicit(self):
         for x, y in [('', ''),
                      ('1', '0'),
                      ('1011', '0000'),
@@ -1820,14 +1830,13 @@ class MethodTests(unittest.TestCase, Util):
             a.bytereverse()
             self.assertEqual(a, bitarray(y))
 
+    def test_bytereverse_byte(self):
         for i in range(256):
             a = bitarray()
             a.frombytes(bytes(bytearray([i])))
-            aa = a.tolist()
-            b = a
+            b = a.copy()
             b.bytereverse()
-            self.assertEqual(b, bitarray(aa[::-1]))
-            self.assertTrue(a is b)
+            self.assertEqual(b, a[::-1])
             self.check_obj(b)
 
 
